==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AlertmanagerFluentImpl<A extends AlertmanagerFluent<A>> extends BaseFluent<A> implements AlertmanagerFluent<A>{
  public AlertmanagerFluentImpl() {
  }
  public AlertmanagerFluentImpl(Alertmanager instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private AlertmanagerSpecBuilder spec;
  private AlertmanagerStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public AlertmanagerFluent.MetadataNested<A> withNewMetadata() {
    return new AlertmanagerFluentImpl.MetadataNestedImpl();
  }
  public AlertmanagerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new AlertmanagerFluentImpl.MetadataNestedImpl(item);
  }
  public AlertmanagerFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public AlertmanagerFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public AlertmanagerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public AlertmanagerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public AlertmanagerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(AlertmanagerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new AlertmanagerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public AlertmanagerFluent.SpecNested<A> withNewSpec() {
    return new AlertmanagerFluentImpl.SpecNestedImpl();
  }
  public AlertmanagerFluent.SpecNested<A> withNewSpecLike(AlertmanagerSpec item) {
    return new AlertmanagerFluentImpl.SpecNestedImpl(item);
  }
  public AlertmanagerFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public AlertmanagerFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new AlertmanagerSpecBuilder().build());
  }
  public AlertmanagerFluent.SpecNested<A> editOrNewSpecLike(AlertmanagerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public AlertmanagerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public AlertmanagerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(AlertmanagerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new AlertmanagerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Integer availableReplicas,Boolean paused,Integer replicas,Integer unavailableReplicas,Integer updatedReplicas) {
    return (A)withStatus(new AlertmanagerStatus(availableReplicas, paused, replicas, unavailableReplicas, updatedReplicas));
  }
  public AlertmanagerFluent.StatusNested<A> withNewStatus() {
    return new AlertmanagerFluentImpl.StatusNestedImpl();
  }
  public AlertmanagerFluent.StatusNested<A> withNewStatusLike(AlertmanagerStatus item) {
    return new AlertmanagerFluentImpl.StatusNestedImpl(item);
  }
  public AlertmanagerFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public AlertmanagerFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new AlertmanagerStatusBuilder().build());
  }
  public AlertmanagerFluent.StatusNested<A> editOrNewStatusLike(AlertmanagerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AlertmanagerFluentImpl that = (AlertmanagerFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<AlertmanagerFluent.MetadataNested<N>> implements AlertmanagerFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) AlertmanagerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends AlertmanagerSpecFluentImpl<AlertmanagerFluent.SpecNested<N>> implements AlertmanagerFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(AlertmanagerSpec item) {
      this.builder = new AlertmanagerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new AlertmanagerSpecBuilder(this);
    }
    AlertmanagerSpecBuilder builder;
    public N and() {
      return (N) AlertmanagerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends AlertmanagerStatusFluentImpl<AlertmanagerFluent.StatusNested<N>> implements AlertmanagerFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(AlertmanagerStatus item) {
      this.builder = new AlertmanagerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new AlertmanagerStatusBuilder(this);
    }
    AlertmanagerStatusBuilder builder;
    public N and() {
      return (N) AlertmanagerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AlertmanagerFluentImpl<A extends AlertmanagerFluent<A>> extends BaseFluent<A> implements AlertmanagerFluent<A>{
  public AlertmanagerFluentImpl() {
  }
  public AlertmanagerFluentImpl(Alertmanager instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private AlertmanagerSpecBuilder spec;
  private AlertmanagerStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public AlertmanagerFluentImpl.MetadataNested<A> withNewMetadata() {
    return new AlertmanagerFluentImpl.MetadataNestedImpl();
  }
  public AlertmanagerFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new AlertmanagerFluentImpl.MetadataNestedImpl(item);
  }
  public AlertmanagerFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public AlertmanagerFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public AlertmanagerFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public AlertmanagerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public AlertmanagerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(AlertmanagerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new AlertmanagerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public AlertmanagerFluentImpl.SpecNested<A> withNewSpec() {
    return new AlertmanagerFluentImpl.SpecNestedImpl();
  }
  public AlertmanagerFluentImpl.SpecNested<A> withNewSpecLike(AlertmanagerSpec item) {
    return new AlertmanagerFluentImpl.SpecNestedImpl(item);
  }
  public AlertmanagerFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public AlertmanagerFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new AlertmanagerSpecBuilder().build());
  }
  public AlertmanagerFluentImpl.SpecNested<A> editOrNewSpecLike(AlertmanagerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public AlertmanagerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public AlertmanagerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(AlertmanagerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new AlertmanagerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Integer availableReplicas,Boolean paused,Integer replicas,Integer unavailableReplicas,Integer updatedReplicas) {
    return (A)withStatus(new AlertmanagerStatus(availableReplicas, paused, replicas, unavailableReplicas, updatedReplicas));
  }
  public AlertmanagerFluentImpl.StatusNested<A> withNewStatus() {
    return new AlertmanagerFluentImpl.StatusNestedImpl();
  }
  public AlertmanagerFluentImpl.StatusNested<A> withNewStatusLike(AlertmanagerStatus item) {
    return new AlertmanagerFluentImpl.StatusNestedImpl(item);
  }
  public AlertmanagerFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public AlertmanagerFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new AlertmanagerStatusBuilder().build());
  }
  public AlertmanagerFluentImpl.StatusNested<A> editOrNewStatusLike(AlertmanagerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AlertmanagerFluentImpl that = (AlertmanagerFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<AlertmanagerFluentImpl.MetadataNested<N>> implements AlertmanagerFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) AlertmanagerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends AlertmanagerSpecFluentImpl<AlertmanagerFluentImpl.SpecNested<N>> implements AlertmanagerFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(AlertmanagerSpec item) {
      this.builder = new AlertmanagerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new AlertmanagerSpecBuilder(this);
    }
    AlertmanagerSpecBuilder builder;
    public N and() {
      return (N) AlertmanagerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends AlertmanagerStatusFluentImpl<AlertmanagerFluentImpl.StatusNested<N>> implements AlertmanagerFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(AlertmanagerStatus item) {
      this.builder = new AlertmanagerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new AlertmanagerStatusBuilder(this);
    }
    AlertmanagerStatusBuilder builder;
    public N and() {
      return (N) AlertmanagerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
